@@ -29,16 +29,13 @@
 #ifndef __CCLIPBOARD_H
 #define __CCLIPBOARD_H
 
-#include "gambas.h"
-#include "widgets.h"
-
-
+#include "main.h"
 
 #ifndef __CCLIPBOARD_CPP
 extern GB_DESC CClipboardDesc[];
 extern GB_DESC CDragDesc[];
 #endif
 
-
+void CDRAG_drag(CWIDGET *source, GB_VARIANT_VALUE *data, char *format);
 
 #endif
