@@ -29,7 +29,7 @@
 #ifndef __CCOLOR_H
 #define __CCOLOR_H
 
-#include "gambas.h"
+#include "main.h"
 
 #ifndef __CCOLOR_CPP
 extern GB_DESC CColorDesc[];
