@@ -34,14 +34,25 @@ public:
 
 	static void setDirty();
 	static int loopLevel() { return _loopLevel; }
-	static void enterLoop();
-	static void exitLoop();
+	static void enterLoop(void *owner, bool showIt = false);
+	static void exitLoop(void *owner);
+	static bool hasLoop(void *owner) { return _loop_owner == owner; }
+	static GtkWindowGroup *enterGroup();
+	static void exitGroup(GtkWindowGroup *oldGroup);
+
+	static bool (*onKeyEvent)(int type);
 
 //"Private"
 	static GtkTooltips *tipHandle();
 	static bool _busy;
 	static char *_title;
 	static int _loopLevel;
+	static void *_loop_owner;
+	static GtkWindowGroup *_group;
+	static GtkWindowGroup *currentGroup();
+	//static void dispatchEnterLeave(gControl *enter);
+	static gControl *_enter;
+	static gControl *_leave;
 };
 
 #endif
