@@ -8,7 +8,7 @@ class gFont : public gShare
 public:
 	gFont();
 	gFont(const char *name);
-	~gFont();
+	virtual ~gFont();
   
   static void assign(gFont **dst, gFont *src = 0) { gShare::assign((gShare **)dst, src); }
   static void set(gFont **dst, gFont *src = 0) { gShare::assign((gShare **)dst, src); src->unref(); }
@@ -19,6 +19,8 @@ public:
 	static const char *familyItem(int pos);
 
 	gFont *copy();
+	void copyTo(gFont *dst);
+	void mergeFrom(gFont *src);
 	int ascent();
 	int descent();
 	bool fixed();
@@ -44,6 +46,7 @@ public:
 	void setUnderline(bool vl);
 
 	const char *toString();
+	const char *toFullString();
 	int width(const char *text, int len = -1);
 	int height(const char *text, int len = -1);
 	int height();
@@ -53,8 +56,18 @@ public:
 	gFont(PangoFontDescription *fd);
 	PangoContext* ct;
 	PangoFontDescription *desc() { return pango_context_get_font_description(ct); }
+	bool isAllSet();
+	void reset();
 	
+	unsigned _bold_set : 1;
+	unsigned _italic_set : 1;
+	unsigned _name_set : 1;
+	unsigned _size_set : 1;
+	unsigned _strikeout_set : 1;
+	unsigned _underline_set : 1;
+
 private:
+	
 	bool uline;
 	bool strike;
 	void realize();
