@@ -170,8 +170,6 @@ GList *gMainWindow::windows = NULL;
 gMainWindow *gMainWindow::_active = NULL;
 gMainWindow *gMainWindow::_current = NULL;
 
-static GtkWindowGroup *_current_group = NULL;
-
 void gMainWindow::initialize()
 {
 	//fprintf(stderr, "new window: %p in %p\n", this, parent());
@@ -302,7 +300,7 @@ gMainWindow::~gMainWindow()
 		emit(SIGNAL(onClose));
 		opened = false;
 		if (GTK_IS_WINDOW(border) && modal())
-			gApplication::exitLoop();
+			gApplication::exitLoop(this);
 	}
 	
 	if (_next_timer)
@@ -437,8 +435,6 @@ void gMainWindow::afterShow()
 
 void gMainWindow::setVisible(bool vl)
 {
-	GtkWindowGroup *group;
-
 	if (vl)
 	{
 		emitOpen();
@@ -447,12 +443,7 @@ void gMainWindow::setVisible(bool vl)
 		
 		if (isTopLevel() && !_xembed)
 		{
-			group = _current_group;
-			if (!group)
-				group = gtk_window_get_group(NULL);
-			
-			//fprintf(stderr, "adding window %p to group %p\n", this, group);
-			gtk_window_group_add_window(group, GTK_WINDOW(border));
+			gtk_window_group_add_window(gApplication::currentGroup(), GTK_WINDOW(border));
 		}
 			
 		_not_spontaneous = !visible;
@@ -550,7 +541,6 @@ bool gMainWindow::modal()
 void gMainWindow::showModal()
 {
   gMainWindow *save;
-  GtkWindowGroup *save_group;
   gMainWindow *active;
 	
 	if (!isTopLevel()) return;
@@ -565,19 +555,13 @@ void gMainWindow::showModal()
 	gtk_window_set_modal(GTK_WINDOW(border), true);
   
   center();
-	show();
-
-	save_group = _current_group;
-	_current_group = gtk_window_group_new();
 
 	//fprintf(stderr, "showModal: begin %p\n", this);
 
-	gApplication::enterLoop();
+	gApplication::enterLoop(this, true);
 	
 	//fprintf(stderr, "showModal: end %p\n", this);
 
-	g_object_unref(_current_group);
-	_current_group = save_group;	
 	_current = save;
 	
 	gtk_window_set_modal(GTK_WINDOW(border), false);
@@ -896,7 +880,7 @@ bool gMainWindow::doClose()
 		_closing = false;
 		
 		if (modal())
-			gApplication::exitLoop();
+			gApplication::exitLoop(this);
   }
   
   if (!opened) // && !modal())
@@ -1061,16 +1045,21 @@ void gMainWindow::reparent(gContainer *newpr, int x, int y)
 		_no_delete = true;
 		gtk_widget_destroy(border);
 		_no_delete = false;
+		
 		border = new_border;
+		registerControl();
 		
 		setParent(newpr);
 		connectParent();
 		borderSignals();
 		initWindow();	
+		
 		setBackground(bg);
 		setForeground(fg);
 		setFont(font());
 		
+		gMenu::checkMenuBar(this);
+		
 		move(x, y);
 		gtk_widget_set_size_request(border, width(), height());
 	}
@@ -1084,14 +1073,17 @@ void gMainWindow::reparent(gContainer *newpr, int x, int y)
 		_no_delete = true;
 		gtk_widget_destroy(border);
 		_no_delete = false;
+		
 		border = new_border;
+		registerControl();
 		
 		parent()->remove(this);
 		parent()->arrange();
 
 		setParent(NULL);
-		initWindow();	
 		borderSignals();
+		initWindow();	
+		
 		setBackground(bg);
 		setForeground(fg);
 		setFont(font());
