@@ -140,10 +140,10 @@ void CSocket_CallBackFromDns(void *_object)
   	THIS->Server.sin_addr.s_addr =inet_addr(THIS->DnsTool->sHostIP);
   	bzero(&(THIS->Server.sin_zero),8);
 	myval=connect(THIS->Socket,(struct sockaddr*)&(THIS->Server), sizeof(struct sockaddr));
-	if (errno==EINPROGRESS) /* this is the good answer : connect in progress */
+	if (!myval || errno==EINPROGRESS) /* this is the good answer : connect in progress */
 	{
 		THIS->iStatus=6;
-		GB.Watch (THIS->Socket,GB_WATCH_WRITE,(void *)CSocket_CallBackConnecting,(long)THIS);
+		GB.Watch (THIS->Socket,GB_WATCH_WRITE,(void *)CSocket_CallBackConnecting, (intptr_t)THIS);
 	}
 	else
 	{
@@ -174,20 +174,14 @@ void CSocket_CallBackFromDns(void *_object)
 /*******************************************************************
  This CallBack is used while waiting to finish a connection process
  ******************************************************************/
-void CSocket_CallBackConnecting(int t_sock,int type,long lParam)
+void CSocket_CallBackConnecting(int t_sock, int type, intptr_t param)
 {
 	struct sockaddr_in myhost;
 	int mylen;
-	struct timespec mywait;
-	void *_object;
-
-	/*	Just sleeping a little to reduce CPU waste	*/
-	mywait.tv_sec=0;
-	mywait.tv_nsec=1000000;
-	nanosleep(&mywait,NULL);
-
-	_object=(void*)lParam;
+	void *_object = (void *)param;
 
+	GB.Watch(THIS->Socket, GB_WATCH_NONE, (void *)CSocket_CallBackConnecting, 0);
+	
 	if (THIS->iStatus!=6) return;
 	/****************************************************
 	Checks if Connection was Stablished or there was
@@ -213,8 +207,8 @@ void CSocket_CallBackConnecting(int t_sock,int type,long lParam)
 	GB.FreeString( &THIS->sLocalHostIP);
 	GB.NewString ( &THIS->sLocalHostIP ,inet_ntoa(myhost.sin_addr),0);
 
-	GB.Watch (THIS->Socket,GB_WATCH_NONE,(void *)CSocket_CallBack,(long)THIS);
-	GB.Watch (THIS->Socket,GB_WATCH_WRITE,(void *)CSocket_CallBack,(long)THIS);
+	//GB.Watch (THIS->Socket,GB_WATCH_NONE,(void *)CSocket_CallBack,(long)THIS);
+	GB.Watch (THIS->Socket,GB_WATCH_READ,(void *)CSocket_CallBack,(intptr_t)THIS);
 
 	THIS->stream.desc=&SocketStream;
 	GB.Ref(THIS);
@@ -226,7 +220,7 @@ void CSocket_CallBackConnecting(int t_sock,int type,long lParam)
 /*******************************************************************
  This CallBack is used while socket is connected to remote host
  ******************************************************************/
-void CSocket_CallBack(int t_sock,int type,long lParam)
+void CSocket_CallBack(int t_sock,int type,intptr_t lParam)
 {
 	char buf[1];
 	struct pollfd mypoll;
@@ -294,17 +288,21 @@ void CSocket_stream_internal_error(void *_object,int ncode)
 int CSocket_stream_open(GB_STREAM *stream, const char *path, int mode, void *data){return -1;}
 int CSocket_stream_seek(GB_STREAM *stream, int64_t pos, int whence){return -1;}
 int CSocket_stream_tell(GB_STREAM *stream, int64_t *pos){return -1;}
+
 int CSocket_stream_flush(GB_STREAM *stream)
 {
 	return 0; /* OK */
 }
+
 int CSocket_stream_handle(GB_STREAM *stream)
 {
-	return 0; /* OK */
+	void *_object = stream->tag;
+	return THIS->Socket;
 }
+
 int CSocket_stream_close(GB_STREAM *stream)
 {
-  void *_object=((void**)stream->_free)[0];
+  void *_object = stream->tag;
 
   if (!THIS ) return -1;
 
@@ -324,9 +322,10 @@ int CSocket_stream_close(GB_STREAM *stream)
   if (THIS->OnClose) THIS->OnClose(_object);
   return 0;
 }
+
 int CSocket_stream_lof(GB_STREAM *stream, int64_t *len)
 {
-	void *_object=((void**)stream->_free)[0];
+  void *_object = stream->tag;
 	int bytes;
 
 	*len=0;
@@ -341,9 +340,10 @@ int CSocket_stream_lof(GB_STREAM *stream, int64_t *len)
 	*len=bytes;
 	return 0;
 }
+
 int CSocket_stream_eof(GB_STREAM *stream)
 {
-	void *_object=((void**)stream->_free)[0];
+  void *_object = stream->tag;
 	int bytes;
 
 	if (!THIS) return -1;
@@ -360,9 +360,9 @@ int CSocket_stream_eof(GB_STREAM *stream)
 
 int CSocket_stream_read(GB_STREAM *stream, char *buffer, int len)
 {
-	void *_object=((void**)stream->_free)[0];
-  	int npos=-1;
-  	int NoBlock=0;
+  void *_object = stream->tag;
+	int npos=-1;
+	int NoBlock=0;
 	int bytes;
 
 	if (!THIS) return -1;
@@ -392,7 +392,7 @@ int CSocket_stream_read(GB_STREAM *stream, char *buffer, int len)
 
 int CSocket_stream_write(GB_STREAM *stream, char *buffer, int len)
 {
-	void *_object=((void**)stream->_free)[0];
+  void *_object = stream->tag;
 	int npos=-1;
 	int NoBlock=0;
 
@@ -442,7 +442,7 @@ int CSocket_connect_unix(void *_object,char *sPath,int lenpath)
   	{
 		THIS->iStatus=7;
 		ioctl(THIS->Socket,FIONBIO,&NoBlock);
-		GB.Watch (THIS->Socket,GB_WATCH_WRITE,(void *)CSocket_CallBack,(long)THIS);
+		GB.Watch (THIS->Socket,GB_WATCH_READ,(void *)CSocket_CallBack,(intptr_t)THIS);
 		THIS->stream.desc=&SocketStream;
                 // $BM
                 if (THIS->Host) GB.FreeString(&THIS->Host);
@@ -515,11 +515,15 @@ int CSocket_connect_socket(void *_object,char *sHost,int lenhost,int myport)
 	THIS->stream.desc=&SocketStream;
   	THIS->iUsePort=THIS->iPort;
 
-        // $BM
-        if (THIS->Host) GB.FreeString(&THIS->Host);
-        if (THIS->Path) GB.FreeString(&THIS->Path);
+	// $BM
+	if (THIS->Path) GB.FreeString(&THIS->Path);
 
-	GB.NewString(&THIS->Host,sHost,0);
+	if (sHost != THIS->Host)
+	{
+		if (THIS->Host) GB.FreeString(&THIS->Host);
+		GB.NewString(&THIS->Host,sHost,0);
+	}
+	
 	return 0;
 
 }
@@ -735,10 +739,8 @@ END_PROPERTY
  ****************************************************/
 BEGIN_METHOD_VOID(CSOCKET_new)
 
-  
-  ((void**)THIS->stream._free)[0]=_object;	
-  THIS->iUsePort=80;
-
+  THIS->stream.tag = THIS;
+  THIS->iUsePort = 80;
 
 END_METHOD
 
@@ -786,7 +788,7 @@ BEGIN_METHOD_VOID(CSOCKET_Peek)
 
   if (THIS->iStatus != 7) /* if socket is not connected we can't receive anything */
   {
-      GB.Error("Socket is not active. Connect it first.");
+      GB.Error("Socket is not active. Connect it first");
       return;
   }
 
@@ -844,8 +846,8 @@ BEGIN_METHOD(CSOCKET_Connect,GB_STRING HostOrPath;GB_INTEGER Port;)
   {
     case 1: GB.Error("Socket is already connected"); return;
     case 2: GB.Error("Invalid path length"); return;
-    case 8: GB.Error("Port value out of range."); return;
-    case 9: GB.Error("Invalid host name."); return;
+    case 8: GB.Error("Port value out of range"); return;
+    case 9: GB.Error("Invalid host name"); return;
   }
 
 END_METHOD
