@@ -131,15 +131,15 @@ PUBLIC char *FILE_make_temp(int *len, char *pattern)
   if (len)
   {
     if (pattern)
-      *len = sprintf(file_buffer, FILE_TEMP_PATTERN, getuid(), getpid(), pattern);
-    else
+      *len = snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_PATTERN, getuid(), getpid(), pattern);
+     else
     {
       count++;
-      *len = sprintf(file_buffer, FILE_TEMP_FILE, getuid(), getpid(), count);
+      *len = snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_FILE, getuid(), getpid(), count);
     }
   }
   else
-    sprintf(file_buffer, FILE_TEMP_DIR, getuid(), getpid());
+    snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_DIR, getuid(), getpid());
 
   return file_buffer;
 }
@@ -168,9 +168,9 @@ PUBLIC void FILE_init(void)
 {
 	FILE_remove_temp_file();
   
-  sprintf(file_buffer, FILE_TEMP_PREFIX, getuid());
+  snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_PREFIX, getuid());
   mkdir(file_buffer, S_IRWXU);
-  sprintf(file_buffer, FILE_TEMP_DIR, getuid(), getpid());
+  snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_DIR, getuid(), getpid());
   mkdir(file_buffer, S_IRWXU);
 }
 
@@ -268,7 +268,6 @@ PUBLIC int FILE_buffer_length(void)
   return file_buffer_length;
 }
 
-
 PUBLIC const char *FILE_get_dir(const char *path)
 {
   char *p;
@@ -498,7 +497,7 @@ PUBLIC void FILE_dir_first(const char *path, const char *pattern, int attr)
     }
 
     file_dir_arch = TRUE;
-    ARCHIVE_dir_first(NULL, path, pattern);
+    ARCHIVE_dir_first(NULL, path, pattern, attr);
     return;
   }
 
@@ -702,8 +701,8 @@ PUBLIC void FILE_copy(const char *src, const char *dst)
 {
   STREAM stream_src;
   STREAM stream_dst;
-  long long len;
-  long long n;
+  int64_t len;
+  int64_t n;
   char *buf = NULL;
 
   CLEAR(&stream_src);
@@ -775,12 +774,12 @@ PUBLIC bool FILE_exist(const char *path)
 
   if (FILE_is_relative(path))
   {
-    if (!EXEC_arch)
+    /*if (!EXEC_arch)
     {
       chdir(PROJECT_path);
       if (lstat(path, &buf) == 0)
         return TRUE;
-    }
+    }*/
 
     return ARCHIVE_exist(NULL, path);
   }
@@ -802,7 +801,7 @@ PUBLIC void FILE_link(const char *src, const char *dst)
     THROW_SYSTEM(errno, dst);
 }
 
-PUBLIC long long FILE_free(const char *path)
+PUBLIC int64_t FILE_free(const char *path)
 {
   struct statfs info;
 
@@ -810,7 +809,7 @@ PUBLIC long long FILE_free(const char *path)
     return 0;
 
   statfs(path, &info);
-  return (long long)(getuid() == 0 ? info.f_bfree : info.f_bavail) * info.f_bsize;
+  return (int64_t)(getuid() == 0 ? info.f_bfree : info.f_bavail) * info.f_bsize;
 }
 
 #else
@@ -859,19 +858,25 @@ PUBLIC const char *FILE_readlink(const char *link)
 
 }
 
-PUBLIC const char *FILE_find_gambas(void)
+PUBLIC const char *FILE_get_gambas_dir(void)
 {
   const char *path;
+	const char *dir;
+	
+	dir = getenv("GB_DIR");
+	if (dir)
+		return dir;
 
   if (FILE_exist(GAMBAS_LINK_PATH))
   {
     path = FILE_readlink(GAMBAS_LINK_PATH);
     if (!path)
       path = GAMBAS_LINK_PATH;
+		return FILE_get_dir(FILE_get_dir(path));
   }
   else
   {
-    path = GAMBAS_PATH "/gbx" GAMBAS_VERSION_STRING;
+		return FILE_get_dir(GAMBAS_PATH);
   }
 
   return path;
